%global systemd_unit gnome-remote-desktop.service

%global tarball_version %%(echo %{version} | tr '~' '.')

# (tv) Needs fdk-aac-free:
%global enable_rdp 1

%global libei_version 1.0.901

Name:           gnome-remote-desktop
Version:        48.1
Release:        %mkrel 3
Summary:        GNOME Remote Desktop screen share service
Group:          Graphical desktop/GNOME

License:        GPLv2+
URL:            https://gitlab.gnome.org/jadahl/gnome-remote-desktop
Source0:        https://download.gnome.org/sources/gnome-remote-desktop/%{url_ver}/%{name}-%{tarball_version}.tar.xz

BuildRequires:  asciidoc
BuildRequires:  gcc
BuildRequires:  glslc
BuildRequires:  meson
BuildRequires:  spirv-tools
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(ffnvcodec)
%if 0%{?enable_rdp}
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(freerdp3)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(winpr3)
%endif
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0) >= 2.68
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libei-1.0) >= %{libei_version}
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libvncserver) >= 0.9.11-7
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(tss2-esys)
BuildRequires:  pkgconfig(tss2-mu)
BuildRequires:  pkgconfig(tss2-rc)
BuildRequires:  pkgconfig(tss2-tctildr)

%{?systemd_requires}
BuildRequires:  systemd

Requires:       pipewire >= 0.3

Obsoletes:      vino < 3.22.0-10

%description
GNOME Remote Desktop is a remote desktop and screen sharing service for the
GNOME desktop environment.


%prep
%autosetup -p1 -n %{name}-%{tarball_version}


%build
%meson \
%if 0%{?enable_rdp}
    -Drdp=true \
%else
    -Drdp=false \
%endif
    -Dsystemd=true \
    -Dtests=false \
    -Dvnc=true
%meson_build


%install
%meson_install

%find_lang %{name}


%post
%systemd_user_post %{systemd_unit}


%preun
%systemd_user_preun %{systemd_unit}


%postun
%systemd_user_postun_with_restart %{systemd_unit}


%files -f %{name}.lang
%license COPYING
%doc README.md
%{_bindir}/grdctl
%{_libexecdir}/gnome-remote-desktop-daemon
%{_libexecdir}/gnome-remote-desktop-configuration-daemon
%{_libexecdir}/gnome-remote-desktop-enable-service
%{_unitdir}/gnome-remote-desktop.service
%{_unitdir}/gnome-remote-desktop-configuration.service
%{_userunitdir}/gnome-remote-desktop-handover.service
%{_userunitdir}/gnome-remote-desktop-headless.service
%{_userunitdir}/%{systemd_unit}
%{_sysusersdir}/gnome-remote-desktop-sysusers.conf
%{_tmpfilesdir}/gnome-remote-desktop-tmpfiles.conf
%{_datadir}/applications/org.gnome.RemoteDesktop.Handover.desktop
%{_datadir}/dbus-1/system-services/org.gnome.RemoteDesktop.Configuration.service
%{_datadir}/dbus-1/system.d/org.gnome.RemoteDesktop.conf
%{_datadir}/polkit-1/actions/org.gnome.remotedesktop.configure-system-daemon.policy
%{_datadir}/polkit-1/actions/org.gnome.remotedesktop.enable-system-daemon.policy
%{_datadir}/polkit-1/rules.d/20-gnome-remote-desktop.rules
%{_datadir}/glib-2.0/schemas/org.gnome.desktop.remote-desktop.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.desktop.remote-desktop.enums.xml
%if 0%{?enable_rdp}
%{_datadir}/gnome-remote-desktop/
%endif
%{_mandir}/man1/grdctl.1*


%changelog
* Tue Jul 08 2025 umeabot <umeabot> 48.1-3.mga10
+ Revision: 2251735
- Mageia 10 Mass Rebuild
+ daviddavid <daviddavid>
- rebuild for new fuse3 3.17.2

* Mon Apr 21 2025 daviddavid <daviddavid> 48.1-1.mga10
+ Revision: 2177405
- new version 48.1

* Thu Mar 20 2025 daviddavid <daviddavid> 48.0-1.mga10
+ Revision: 2167079
- new version 48.0

* Sun Dec 01 2024 daviddavid <daviddavid> 47.2-1.mga10
+ Revision: 2120198
- new version 47.2

* Fri Nov 01 2024 daviddavid <daviddavid> 47.1-1.mga10
+ Revision: 2111928
- new version 47.1

* Wed Sep 18 2024 daviddavid <daviddavid> 47.0-1.mga10
+ Revision: 2098426
- new version 47.0

* Sun Jun 02 2024 daviddavid <daviddavid> 46.2-1.mga10
+ Revision: 2069292
- new version 46.2

* Mon Mar 18 2024 daviddavid <daviddavid> 46.0-1.mga10
+ Revision: 2050584
- new version 46.0

* Thu Dec 07 2023 daviddavid <daviddavid> 45.1-1.mga10
+ Revision: 2014179
- new version 45.1

* Sat Sep 30 2023 tv <tv> 45.0-1.mga10
+ Revision: 1992585
- Update to 45.0

* Sat Jun 03 2023 daviddavid <daviddavid> 44.2-1.mga9
+ Revision: 1960768
- new version 44.2

* Mon Apr 24 2023 neoclust <neoclust> 44.1-1.mga9
+ Revision: 1954666
- New version 44.1

* Sat Apr 22 2023 tmb <tmb> 44.0-1.mga9
+ Revision: 1953962
- update to 44.0
- update to 44.0

* Fri Dec 09 2022 ghibo <ghibo> 43.2-1.mga9
+ Revision: 1919882
- Update to release 43.2
+ tv <tv>
- Explicitely enable fdk-aac

* Sat Nov 12 2022 wally <wally> 43.1-2.mga9
+ Revision: 1906556
- obsolete vino (mga#31104)

* Sat Oct 22 2022 ovitters <ovitters> 43.1-1.mga9
+ Revision: 1898573
- new version 43.1

* Sun Sep 25 2022 tv <tv> 43.0-1.mga9
+ Revision: 1892332
- Re-enable rdp
- Disable RDP as needed fdk-aac is only in tainted
- Update to 43.0

* Sat Sep 17 2022 ovitters <ovitters> 42.5-1.mga9
+ Revision: 1889591
- new version 42.5

* Sat Aug 06 2022 ovitters <ovitters> 42.4-1.mga9
+ Revision: 1875687
- new version 42.4

* Tue Jul 12 2022 tv <tv> 42.3-2.mga9
+ Revision: 1868556
- Call systemd on uninstall

* Sun Jul 03 2022 ovitters <ovitters> 42.3-1.mga9
+ Revision: 1867197
- new version 42.3
- new version 42.2

* Tue Apr 26 2022 ovitters <ovitters> 42.1.1-1.mga9
+ Revision: 1854382
- new version 42.1.1
- new version 42.1

* Tue Mar 22 2022 tv <tv> 42.0-1.mga9
+ Revision: 1816808
- Update to 42.0
- Update to 42.rc

* Wed Jan 12 2022 tv <tv> 41.2-1.mga9
+ Revision: 1768141
- 41.2

* Wed Sep 15 2021 ovitters <ovitters> 40.2-1.mga9
+ Revision: 1745495
- new version 40.2

* Wed May 05 2021 ovitters <ovitters> 40.1-1.mga9
+ Revision: 1721514
- new version 40.1

* Wed Mar 24 2021 ovitters <ovitters> 40.0-1.mga9
+ Revision: 1709447
- new version 40.0

* Sat Sep 12 2020 tv <tv> 0.1.9-1.mga8
+ Revision: 1624986
- BR freerdp2
- BR pkgconfig(cairo)
+ daviddavid <daviddavid>
- new version 0.1.9
- update Source URL

* Mon Apr 13 2020 ovitters <ovitters> 0.1.8-1.mga8
+ Revision: 1567139
- remove empty postun macro
- add group
- new version 0.1.8
- drop patch we never had and does not apply
- Mageify the spec
- from Fedora


* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Mar 4 2019 Jonas Ådahl <jadahl@redhat.com> - 0.1.7-1
- Update to 0.1.7

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Oct 2 2018 Jonas Ådahl <jadahl@redhat.com> - 0.1.6-2
- Don't crash when PipeWire disconnects (rhbz#1632781)

* Tue Aug 7 2018 Jonas Ådahl <jadahl@redhat.com> - 0.1.6
- Update to 0.1.6
- Apply ANON-TLS patch
- Depend on pipewire 0.2.2

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed May 30 2018 Jonas Ådahl <jadahl@redhat.com> - 0.1.4-1
- Update to new version

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.1.2-5
- Escape macros in %%changelog

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Aug 29 2017 Jonas Ådahl <jadahl@redhat.com> - 0.1.2-3
- Use %%autosetup
- Install licence file

* Tue Aug 22 2017 Jonas Ådahl <jadahl@redhat.com> - 0.1.2-2
- Remove gschema compilation step as that had been deprecated

* Mon Aug 21 2017 Jonas Ådahl <jadahl@redhat.com> - 0.1.2-1
- Update to 0.1.2
- Changed tabs to spaces
- Added systemd user macros
- Install to correct systemd user unit directory
- Compile gsettings schemas after install and uninstall

* Mon Aug 21 2017 Jonas Ådahl <jadahl@redhat.com> - 0.1.1-1
- First packaged version
